#!/usr/bin/env python3
""" Portfolio Value report """

def main(args):
    """ Main entry point. Useful for calling from cli script or unit tests """
    from pydatum import Datum
    from gnucash_portfolio.reports import portfolio_value
    #from gnucash_portfolio.model.stock_model import StockViewModel
    from gnucash_portfolio.reports.portfolio_models import PortfolioValueInputModel
    #, PortfolioValueViewModel

    parameters = PortfolioValueInputModel()
    today = Datum()
    today.today()
    parameters.as_of_date = today.value
    model = portfolio_value.run(parameters)

    # Display
    print_row("security", "cost", "balance", "gain/loss", "%", "income", "inc.12m", "%")
    print("-" * 120)

    rows = sorted(model.stock_rows, key=lambda row: f"{row.exchange}:{row.symbol}")

    for row in rows:
        col1 = f"{row.exchange}:{row.symbol}"
        col2 = f"{row.shares_num:,} @ {row.avg_price:,.2f} {row.currency} = {row.cost:,.2f}"
        col3 = f"@ {row.price:,.2f} = {row.balance:,.2f}"
        col4 = f"{row.gain_loss:,.2f}"
        col5 = f"{row.gain_loss_perc:,.2f}%"
        col6 = f"{row.income:,.2f}"
        col7 = f"{row.income_last_12m:,.2f}"
        col8 = f"{row.income_last_12m_perc:,.2f}"

        print_row(col1, col2, col3, col4, col5, col6, col7, col8)


def print_row(col1, col2, col3, col4, col5, col6, col7, col8):
    """ Print the values in one row """
    line = f"{col1:<15} {col2:>32} {col3:>20} {col4:>10} {col5:>8} {col6:>8} {col7:>8} {col8:>5}"
    print(line)


if __name__ == "__main__":
    main(None)



#!/usr/bin/env python3
"""
Testing webview library for opening up a native web view as a UI client.
"""
import webview

#webview.create_window("It works, Jim!", "http://www.flowrl.com")
webview.create_window("yo!", "http://alensiljak.ml")



#!/usr/bin/env python3
"""
List upcoming scheduled transactions.
Allow for setting the period. By default, use 2 weeks?
"""

def main(args=None):
    from gnucash_portfolio import BookAggregate

    book = BookAggregate()
    # Return next 15 transactions.
    txs = book.scheduled.get_upcoming(15)
    # display
    for tx in txs:
        agg = book.scheduled.get_aggregate_for(tx)
        next_date = agg.get_next_occurrence()
        print(f"{next_date}, {tx.name}")


if __name__ == "__main__":
    main()



#!/usr/bin/env python3
""" search for security """
import argparse
from gnucash_portfolio import BookAggregate

def read_parameters():
    """ Read parameters from the command line """
    parser = argparse.ArgumentParser(description='read symbol from command line')

    parser.add_argument('search_term', type=str, help='The term to search for in security description or symbol')

    args = parser.parse_args()
    return args

def main():
    """ Main method, for unit testing """
    # Get parameter from command line
    args = read_parameters()

    book = BookAggregate()
    securities = book.securities.find(args.search_term)
    securities = sorted(securities, key=lambda security: security.namespace + ":" + security.mnemonic)

    for security in securities:
        print(f"{security.namespace}:{security.mnemonic} {security.fullname}")

if __name__ == "__main__":
    main()



""" Tests for scheduled transactions script """


def test_creation():
    """ Call the cli and test scheduler tx script """
    from gnucash_portfolio_cli import gpcli
    #gpcli.main("scheduled")
    pass



""" The minimal setup """

from setuptools import setup

setup(name='gnucash_portfolio_cli',
      version='1.5.1',
      description='command-line interface to Gnucash Portfolio',
      url='https://github.com/MisterY/gnucash-portfolio-cli',
      author='Alen Siljak',
      author_email='alen.siljak@gmx.com',
      license='GPL version 3',
      packages=['gnucash_portfolio_cli'],
      install_requires=['gnucash_portfolio'],
      entry_points={
        'console_scripts': [
            'gpcli=gnucash_portfolio_cli.gpcli:main',
        ],
    },
)
